package Qt::Xml::QDomDocumentType;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QDomDocumentType
# file     : QtXml/qdom.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_02';
our $ISA     = qw/Qt::Xml::QDomNode/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Xml::QDomDocumentType

=head1 PUBLIC METHODS

=over

=item   QDomDocumentType()

=item   QDomDocumentType()

=item  QDomNamedNodeMap entities()

=item  QString internalSubset()

=item  QString name()

=item  QDomNode::NodeType nodeType()

=item  QDomNamedNodeMap notations()

=item  QDomDocumentType & operator=()

=item  QString publicId()

=item  QString systemId()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
